@@ -1,20 +1,18 @@
 #' NatureServe taxonomic name search
 #'
 #' @export
-#' @param x (character) A name to search for. An asterisk (*) wildcarded species
-#' name, e.g., 'Aquila chry*'. Name matching is case-insensitive and all of
-#' the primary and synonymous scientific names, along with all common names,
-#' are matched. Required.
+#' @param x (character) A name to search for. An asterisk (*) wildcarded
+#' species name, e.g., 'Aquila chry*'. Name matching is case-insensitive
+#' and all of the primary and synonymous scientific names, along with
+#' all common names, are matched. required.
 #' @template ns
-#'
 #' @return A tibble (data.frame), with columns:
-#' \itemize{
-#'  \item jurisdictionScientificName - Scientfic name
-#'  \item commonName - Common name
-#'  \item globalSpeciesUid - UID - the taxonomic identifier NatureServe uses
-#'  \item natureServeExplorerURI - URL to get to info online for the taxon
-#'  \item taxonomicComments - comments about the taxon, if any
-#' }
+#'
+#' - jurisdictionScientificName - Scientfic name
+#' - commonName - Common name
+#' - globalSpeciesUid - UID - the taxonomic identifier NatureServe uses
+#' - natureServeExplorerURI - URL to get to info online for the taxon
+#' - taxonomicComments - comments about the taxon, if any
 #'
 #' @examples \dontrun{
 #' ns_search(x = "Ruby*")
@@ -22,9 +20,11 @@
 #' ns_search(x = "Ursus americanus")
 #' }
 ns_search <- function(x, key = NULL, ...) {
+  assert(x, "character")
   res <- ns_GET(
     url = paste0(ns_base(), '/v1/globalSpecies/list/nameSearch'),
-    query = list(name = gsub("\\s", "%20", x), NSAccessKeyId = check_key(key)),
+    query = list(name = x, NSAccessKeyId = check_key(key)),
+    err_fxn = err_catch_search,
     ...
   )
   xml <- xml2::read_xml(res)
@@ -36,5 +36,5 @@ ns_search <- function(x, key = NULL, ...) {
   })
   df <- data.table::setDF(data.table::rbindlist(dat, use.names = TRUE, fill = TRUE))
   df <- move_col2(df, "natureServeExplorerURI")
-  tibble::as_data_frame(df)
+  tibble::as_tibble(df)
 }
